=== modified file 'lib/lp/app/javascript/formoverlay/formoverlay.js'
--- lib/lp/app/javascript/formoverlay/formoverlay.js	2011-07-21 09:27:45 +0000
+++ lib/lp/app/javascript/formoverlay/formoverlay.js	2011-08-19 15:28:07 +0000
@@ -27,6 +27,7 @@
 
     Y.after(this._renderUIFormOverlay, this, RENDERUI);
     Y.after(this._bindUIFormOverlay, this, BINDUI);
+    Y.after(this._bindDestroyOnHide, this, BINDUI);
 
 }
 
@@ -184,6 +185,19 @@
      */
     form_submit_callback: {
         value: null
+    },
+
+    /**
+     * A boolean indicating whether or not this overlay should destroy
+     * itself when hidden.
+     *
+     * @attribute destroy_on_hide
+     * @type: boolean
+     * @default: false
+     */
+    destroy_on_hide: {
+        value: false,
+        writeOnce: "initOnly"
     }
 };
 
@@ -270,6 +284,23 @@
     },
 
     /**
+     * If destroy_on_hide, call the destroy method when this formoverlay
+     * is hidden.
+     *
+     * @method _bindDestroyOnHide
+     * @protected
+     */
+    _bindDestroyOnHide: function(){
+        if (this.get('destroy_on_hide')) {
+            this.after('visibleChange', function(e) {
+                if (!e.newVal) {
+                    this.destroy();
+                }
+            });
+        }
+    },
+
+    /**
      * Setup and add the form to the DOM.
      *
      * @method _setFormContent

=== modified file 'lib/lp/app/javascript/formoverlay/tests/test_formoverlay.js'
--- lib/lp/app/javascript/formoverlay/tests/test_formoverlay.js	2011-07-08 05:12:39 +0000
+++ lib/lp/app/javascript/formoverlay/tests/test_formoverlay.js	2011-08-19 15:28:07 +0000
@@ -264,9 +264,35 @@
         Assert.isTrue(centered,
             "The overlay centers itself when it is shown with the centered " +
             "attribute set.");
+    },
+
+    test_destroy_on_hide: function() {
+        this.destroy_form_overlay = make_form_overlay({
+            destroy_on_hide: true,
+            headerContent: 'Form for testing',
+            form_content: [
+                'Here is an input: ',
+                '<input type="text" name="field1" id="field1" />',
+                'Here is another input: ',
+                '<input type="text" name="field2" id="field2" />'].join(""),
+            xy: [0, 0]
+        });
+
+        var destroy_fired = false;
+        var onDestroy = function(e) {
+            destroy_fired = true;
+        };
+        this.destroy_form_overlay.on('destroy', onDestroy);
+
+        this.destroy_form_overlay.hide();
+
+        Assert.isTrue(
+            destroy_fired,
+            "The destroy event should have been fired.");
     }
 }));
 
+
 suite.add(new Y.Test.Case({
 
     name: 'form_overlay_data',
@@ -414,7 +440,7 @@
         var external_form_content = '<div id="loaded-content"></div>';
 
         var form_overlay = make_form_overlay({
-            headerContent: 'Form for testing',
+            headerContent: 'Form for testing'
             });
         var mock_io = new Y.lazr.testing.MockIo();
         form_overlay.loadFormContentAndRender(
@@ -434,7 +460,8 @@
         // checking the form content is present in the HTML.
         var form_node_text = form_overlay.form_node.get('innerHTML');
         Assert.areEqual(
-            external_form_content, form_node_text.match(external_form_content),
+            external_form_content,
+            form_node_text.match(external_form_content),
             "Failed to render the form.");
         cleanup_form_overlay(form_overlay);
     },
@@ -443,7 +470,7 @@
         // If something goes wrong when loading the form contents, an
         // error message is displayed.
         var form_overlay = make_form_overlay({
-            headerContent: 'Form for testing',
+            headerContent: 'Form for testing'
             });
         var mock_io = new Y.lazr.testing.MockIo();
         form_overlay.loadFormContentAndRender(
@@ -456,7 +483,7 @@
             'failure');
         mock_io.simulateXhr(response, true);
 
-        var error_message = "Sorry, an error occurred while loading the form."
+        var error_message = "Sorry, an error occurred while loading the form.";
         Assert.areEqual(
             error_message, form_overlay.get('form_content'),
             "Failure to set form content.");

=== modified file 'lib/lp/registry/javascript/distroseriesdifferences_details.js'
--- lib/lp/registry/javascript/distroseriesdifferences_details.js	2011-08-11 13:58:54 +0000
+++ lib/lp/registry/javascript/distroseriesdifferences_details.js	2011-08-19 14:59:06 +0000
@@ -302,7 +302,8 @@
             form_submit_button: submit_button,
             form_cancel_button: cancel_button,
             form_submit_callback: submit_callback,
-            visible: true
+            visible: true,
+            destroy_on_hide: true
         });
         overlay.render();
         return overlay;

